//@flow
import React from 'react';
import {
  View,
} from 'react-native';
import FastImage from 'react-native-fast-image';
import Text from '../../components/Text';
import {
  BANNER, TITLE, LIST_ITEM, CHOOSE,
} from './config';
import BasicIcon from "../../components/BasicIcon";
import { ListItem } from "react-native-elements";

function renderBanner(props) {
  console.log('renderBanner:', props);
  return (
    <FastImage
      style={{ width: props.width, height: props.height }}
      source={{
        uri: props.uri,
        priority: FastImage.priority.normal,
      }}
      resizeMode={FastImage.resizeMode.stretch}
    />
  );
}

function renderTitle(props) {
  console.log('renderTitle:', props);
  return (
    <View
      style={{
        height: props.height || 100,
        paddingLeft: 15,
      }}
    >
      <Text style={{
        color: '#333',
        fontSize: 18,
        marginTop:15,
      }}
      >
        {props.h1}
      </Text>
      <Text style={{
        marginTop:10,
        color: '#999',
        fontSize: 13,
      }}
      >
        {props.h2}
      </Text>
      <View style={{
        flexDirection: 'row',
        alignItems: 'center',
        paddingTop: 9,
      }}
      >
        {
          props.label.map((item, index) => (
            <View
              style={{
                borderColor: props.labelColor,
                borderWidth: 1,
                marginRight: 10,
              }}
            >
              <Text style={{
                color: props.labelColor,
              }}
              >
                {item}
              </Text>
            </View>
          ))
        }
      </View>
    </View>
  );
}
function renderListItem(props) {

  return(
    <View>
      {
    <ListItem
      key={`renderListItem${index}`}
      containerStyle={{
        borderBottomWidth: index < props.data.length - 1 ? 0.3 : 0,
        borderBottomColor: '#ccc',
      }}
      title={item.title}
      titleStyle={{ color: '#666', fontSize: 14 }}
      leftElement={(
        <FastImage
          style={{ width: 24, height: 24 }}
          source={{
            uri: item.imgUrl,
            priority: FastImage.priority.normal,
          }}
          resizeMode={FastImage.resizeMode.stretch}
        />
      )}
      rightElement={(
        <BasicIcon
          suite="Ionicons"
          name="ios-arrow-forward"
          size={24}
          color="#666"
        />
      )}
    />}
    </View>
  )
}


export function renderPageByConfig(config, renderCustomView?) {
  switch (config.type) {
  case BANNER:
    return renderBanner;
  case TITLE:
    return renderTitle;
    case LIST_ITEM:
    return renderListItem;
  case CHOOSE:
  default:
    return () => {
      // 有自定义方法执行传入的渲染方法
      if (renderCustomView) {
        renderCustomView(config);
      }
    };
  }
}

export default {
  renderPageByConfig,
};
